.cardPlayedIndicator,.cardTimerIndicator,.cardUserDisabledIcon{border-radius:100em;font-size:1.1em;height:1.25em;width:1.25em;display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center;-webkit-justify-content:center;justify-content:center;top:.18em;position:absolute;right:.18em;inset-inline-start:initial;inset-inline-end:.18em;contain:layout style}.cardTimerIndicator{font-size:1.28em}.cardUserDisabledIcon{font-size:1.4em;color:#777;background:#d3d3d3;height:1.4em;width:1.4em}.cardPlayedIndicator+.cardTimerIndicator{right:1.5em;inset-inline-start:initial;inset-inline-end:1.5em}.cardCountIndicator{display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center;-webkit-justify-content:center;justify-content:center;top:.225em;position:absolute;right:.225em;inset-inline-start:initial;inset-inline-end:.225em;contain:layout style}.cardProgramIndicator{contain:layout style;display:-webkit-inline-flex;display:inline-flex;margin-top:0;margin-bottom:.2em;-webkit-margin-start:.35em;margin-inline-start:.35em;-webkit-margin-end:0;margin-inline-end:0;padding:.08em .5em;border-radius:.42em;-webkit-align-items:center;align-items:center;-webkit-justify-content:center;justify-content:center;text-transform:uppercase;text-shadow:none;font-size:86%;font-weight:600}.appfooter-drag-reorder-active{display:none!important}.dragClone .cardBox{transition:-webkit-transform ease-out .3s!important;transition:transform ease-out .3s!important}.dragClone.dragging .cardBox{-webkit-transform:scale(70%)!important;transform:scale(70%)!important}.dragClone .cardOverlayContainer{display:none!important}.cardIndicatorIcon{font-size:1.6em;top:.225em;left:.225em;inset-inline-start:.225em;inset-inline-end:initial;position:absolute;color:#fff}.cardIndicatorIcon-dragHandle{right:.225em;inset-inline-start:initial;inset-inline-end:.225em;text-shadow:.14em .14em .28em rgba(0,0,0,.45);cursor:pointer}.cardMediaInfoItems{display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center;-webkit-justify-content:center;justify-content:center;-webkit-column-gap:initial!important;column-gap:initial!important;-webkit-flex-wrap:nowrap;flex-wrap:nowrap}.cardMediaInfoItem{-webkit-align-items:center;align-items:center;-webkit-justify-content:center;justify-content:center}.cardMediaInfoItem+.cardMediaInfoItem{-webkit-margin-start:.5em!important;margin-inline-start:.5em!important}.cardMediaInfoItem .starIcon{line-height:.96}.card.dragging-over{position:relative;contain:none!important;z-index:1}.dragging-over-left::before{content:' ';width:.24em;position:absolute;top:.8em;bottom:.8em;left:-.14em;inset-inline-start:-.14em;inset-inline-end:initial;z-index:99999;border-radius:100em}.dragging-over-right::after{content:' ';width:.24em;position:absolute;right:-.14em;top:.8em;bottom:.8em;inset-inline-start:initial;inset-inline-end:-.14em;z-index:99999;border-radius:100em}.cardProgressBarContainer{background:0 0!important;height:.22em}.visualCardBox-vibrant-lg::before{content:" ";position:absolute;top:0;bottom:0;left:0;right:0;inset-inline-start:0;inset-inline-end:0;background:rgba(0,0,0,.2);z-index:-1}.autoWidthCardBox{contain:layout style}.card:focus .cardContent-bxsborder{contain:initial;content-visibility:initial;overflow:visible}.card:focus-visible .cardContent-bxsborder-fv{contain:initial;content-visibility:initial;overflow:visible}.sideFooterCard:focus .cardBox-sideFooter-f{overflow:visible}.sideFooterCard:focus .cardContent-sideFooter-f{border-start-start-radius:inherit;border-end-start-radius:inherit}.card:focus .cardContent-bxsborder::before{content:" ";position:absolute;top:-.34em;left:-.34em;right:-.34em;bottom:-.34em;border-width:.22em;border-style:solid;border-radius:.6em}.card:focus-visible .cardContent-bxsborder-fv::before{content:" ";position:absolute;top:-.34em;left:-.34em;right:-.34em;bottom:-.34em;border-width:.22em;border-style:solid;border-radius:.6em}.card:focus .cardContent-round::before{border-radius:100em}.cardImage-bxsborder{border-radius:inherit}.cardImage-bxsborder-fv{border-radius:inherit}.buttonCardBox{border-radius:100em;margin:.4em}.buttonCardBox::before,.cardBox-sideFooter::before{display:none!important}.cardText-watching{visibility:hidden}.cardText-currentwatching{visibility:visible}