.emby-select{display:block;margin:0;margin-bottom:0!important;font-size:inherit;font-family:inherit;font-weight:inherit;padding-top:0;padding-bottom:0;box-sizing:border-box;outline:0!important;-webkit-tap-highlight-color:transparent;width:100%;border-radius:.3em;-webkit-appearance:none;appearance:none;letter-spacing:inherit;height:100%}.emby-select-nopointer{pointer-events:none}.emby-select[disabled]{background:0 0!important;border-color:transparent!important;color:inherit!important;-webkit-appearance:none;appearance:none;-webkit-backdrop-filter:none!important;backdrop-filter:none!important;box-shadow:none!important;pointer-events:none}.emby-select[multiple] option{display:none!important;visibility:hidden!important}.emby-select-inline{border-radius:100em;-webkit-flex-grow:1;flex-grow:1;line-height:normal}.emby-select-inline-getitems{position:absolute;top:0;left:0;right:0;bottom:0}.emby-select-inline[disabled]{-webkit-padding-start:0;padding-inline-start:0;-webkit-padding-end:0;padding-inline-end:0;border-color:transparent!important;text-shadow:inherit}.emby-select::-moz-focus-inner{border:0}.emby-select-focusscale{transition:-webkit-transform .2s ease-out!important;transition:transform .2s ease-out!important;-webkit-transform-origin:center center;transform-origin:center center}.emby-select-focusscale:focus{-webkit-transform:scale(1.025);transform:scale(1.025);z-index:1}.emby-select-inline.emby-select-focusscale:focus{-webkit-transform:scale(1.1);transform:scale(1.1);z-index:1}.selectContainer{margin-bottom:1.5em;position:relative;-webkit-user-select:none;user-select:none}.selectContainer-inline{display:-webkit-inline-flex;display:inline-flex;margin-bottom:0;-webkit-align-items:center;align-items:center}.emby-select-wrapper{position:relative;height:3em}@media all and (pointer:fine){.emby-select-wrapper-smaller{height:2.4em}}.emby-select-wrapper-inline{height:2.2em}@media not all and (pointer:fine){.emby-select-wrapper-inline{height:2.4em}}.emby-select-wrapper-inline-disabled{height:1.65em}.selectLabelText{display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center;margin-bottom:.1em}.selectLabelText-inline{margin-bottom:0;-webkit-margin-end:.5em;margin-inline-end:.5em}.selectLabel-inline{margin-bottom:0;-webkit-flex-shrink:0;flex-shrink:0;display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center}.emby-select[multiple]{color:transparent!important}.emby-select-selectedNameContainer{position:absolute;top:0;bottom:0;left:0;right:0;color:inherit;pointer-events:none;-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;text-shadow:none}.emby-select,.emby-select-selectedNameContainer{-webkit-padding-start:1ch;padding-inline-start:1ch;-webkit-padding-end:3.6ch;padding-inline-end:3.6ch}.emby-select-selectedNameContainer-inline{font-size:inherit;position:relative;height:100%}.emby-select-selectedName{overflow:hidden;white-space:nowrap;text-overflow:ellipsis;display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center}.selectArrowContainer{position:absolute;display:-webkit-flex;display:flex;top:.15em;bottom:.15em;right:.15em;inset-inline-start:initial;inset-inline-end:.15em;color:inherit;pointer-events:none;-webkit-align-items:center;align-items:center;text-shadow:none;border-radius:.3em}.selectArrowContainer-inline{font-size:90%;right:.5em;inset-inline-start:initial;inset-inline-end:.5em}.emby-select[disabled]+.selectArrowContainer{display:none}.emby-select[disabled]+.selectArrowContainer+.emby-select-selectedNameContainer{-webkit-padding-start:0;padding-inline-start:0;-webkit-padding-end:0;padding-inline-end:0;opacity:.7}.selectArrow{font-size:1.7em}.emby-select-iconbutton{-webkit-align-self:flex-end;align-self:flex-end}